@@ -1,6 +1,7 @@
 package Net::Ping::External;
 
 # Author:   Colin McMillen (colinm@cpan.org)
+# Thanks to Randy Moore for fixes to _ping_win32.
 #
 # Copyright (c) 2001 Colin McMillen.  All rights reserved.  This
 # program is free software; you may redistribute it and/or modify it
@@ -11,7 +12,7 @@ use Carp;
 use Socket qw(inet_ntoa);
 require Exporter;
 
-$VERSION = "0.06";
+$VERSION = "0.09";
 @ISA = qw(Exporter);
 @EXPORT = qw();
 @EXPORT_OK = qw(ping);
@@ -33,14 +34,16 @@ sub ping {
   my %dispatch = 
     (linux    => \&_ping_linux,
      mswin32  => \&_ping_win32,
+     cygwin   => \&_ping_win32,
      solaris  => \&_ping_solaris,
      bsdos    => \&_ping_bsdos,
      beos     => \&_ping_beos,
      hpux     => \&_ping_hpux,
      dec_osf  => \&_ping_dec_osf,
      bsd      => \&_ping_bsd,
+     darwin   => \&_ping_unix,
      openbsd  => \&_ping_unix,
-     freebsd  => \&_ping_unix,
+     freebsd  => \&_ping_freebsd,
      next     => \&_ping_next,
      unicosmk => \&_ping_unicosmk,
      netbsd   => \&_ping_unix,
@@ -57,14 +60,13 @@ sub ping {
 
 # Win32 is the only system so far for which we actually need to parse the
 # results of the system ping command.
-
 sub _ping_win32 {
   my %args = @_;
   $args{timeout} *= 1000;    # Win32 ping timeout is specified in milliseconds
   my $command = "ping -l $args{size} -n $args{count} -w $args{timeout} $args{host}";
   print "$command\n" if $DEBUG;
   my $result = `$command`;
-  return 1 if $result =~ /\(0% loss\)/i;
+  return 1 if $result =~ /time?\d*ms/;
   return 0;
 }
 
@@ -151,7 +153,7 @@ sub _ping_bsd {
 }
 
 # Debian 2.2 OK, RedHat 6.2 OK
-# -s size option available to superuser... fixme?
+# -s size option available to superuser... FIXME?
 sub _ping_linux {
   my %args = @_;
   my $command = "ping -c $args{count} $args{host}";
@@ -165,6 +167,14 @@ sub _ping_solaris {
   return _ping_system($command, 0);
 }
 
+# FreeBSD. Tested OK for Freebsd 4.3
+# -s size option supported -- superuser only... FIXME?
+# -w timeout option for BSD replaced by -t
+sub _ping_freebsd {
+ my %args = @_;
+ my $command = "ping -c $args{count} -t $args{timeout} $args{host}";
+ return _ping_system($command, 0);
+}
 
 1;
 
@@ -287,7 +297,10 @@ Default value: 56.
 =head2 SUPPORTED PLATFORMS
 
 Support currently exists for interfacing with the standard ping
-utilities on the following systems:
+utilities on the following systems. Please note that the path to the `ping'
+should be somewhere in your PATH environment variable (or your system's
+closest equivalent thereof.) Otherwise, Net::Ping::External will be unable
+to locate your system's `ping' command.
 
 =over 4
 
@@ -353,8 +366,19 @@ Colin McMillen (colinm@cpan.org)
 This library is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
+=head1 CREDITS
+
+Dan Moore contributed command-line options and code for NeXT, BeOS,
+HP-UX, and BSD/OS.
+
+Jarkko Hietaniemi contributed a huge list of command-line options and results
+for the `ping' command on 9 different systems.
+
 =head1 SEE ALSO
 
 Net::Ping
 
 =cut
+
+
+
